@@ -25,10 +25,11 @@
 /* For clist */
 #undef GTK_DISABLE_DEPRECATED
 
-#include <libgnome/libgnome.h>
-#include <libgnomeui/libgnomeui.h>
+#include <gtk/gtk.h>
 #include <glade/glade.h>
 
+#include "ve-i18n.h"
+
 #include "ve-misc.h"
 #include "ve-miscui.h"
 
@@ -171,6 +172,7 @@ glade_helper_bad_interface (const char *filename, const char *widget,
 	GtkWidget *dlg;
 	char *typestring;
 	const char *typename;
+	char *tmp;
 
 	if (type != 0)
 		typename = g_type_name (type);
@@ -181,11 +183,14 @@ glade_helper_bad_interface (const char *filename, const char *widget,
 		typestring = g_strdup_printf (" (%s)", typename);
 	else
 		typestring = g_strdup ("");
+
+	tmp = ve_filename_to_utf8 (filename);
 	
 	dlg = ve_hig_dialog_new (NULL /* parent */,
 				 0 /* flags */,
 				 GTK_MESSAGE_ERROR,
 				 GTK_BUTTONS_OK,
+				 FALSE /* markup */,
 				 _("Cannot load user interface"),
 				 _("An error occured while loading the user "
 				   "interface element %s%s from file %s.  "
@@ -196,7 +201,7 @@ glade_helper_bad_interface (const char *filename, const char *widget,
 				   "installation of %s or reinstall %s."),
 				 widget,
 				 typestring,
-				 filename,
+				 tmp,
 				 PACKAGE,
 				 PACKAGE,
 				 PACKAGE);
@@ -205,7 +210,9 @@ glade_helper_bad_interface (const char *filename, const char *widget,
 
 	g_warning (_("Glade file is on crack! Make sure the correct "
 		     "file is installed!\nfile: %s widget: %s"),
-		   filename, widget);
+		   tmp, widget);
+
+	g_free (tmp);
 
 	gtk_dialog_run (GTK_DIALOG (dlg));
 	gtk_widget_destroy (dlg);
@@ -218,6 +225,7 @@ glade_helper_bad_columns (const char *filename, const char *widget,
 	GtkWidget *dlg;
 	char *typestring;
 	const char *typename;
+	char *tmp;
 
 	if (type != 0)
 		typename = g_type_name (type);
@@ -228,11 +236,14 @@ glade_helper_bad_columns (const char *filename, const char *widget,
 		typestring = g_strdup_printf (" (%s)", typename);
 	else
 		typestring = g_strdup ("");
+
+	tmp = ve_filename_to_utf8 (filename);
 	
 	dlg = ve_hig_dialog_new (NULL /* parent */,
 				 0 /* flags */,
 				 GTK_MESSAGE_ERROR,
 				 GTK_BUTTONS_OK,
+				 FALSE /* markup */,
 				 _("Cannot load user interface"),
 				 _("An error occured while loading the user "
 				   "interface element %s%s from file %s.  "
@@ -244,7 +255,7 @@ glade_helper_bad_columns (const char *filename, const char *widget,
 				   "installation of %s or reinstall %s."),
 				 widget,
 				 typestring,
-				 filename,
+				 tmp,
 				 columns,
 				 PACKAGE,
 				 PACKAGE,
@@ -255,7 +266,9 @@ glade_helper_bad_columns (const char *filename, const char *widget,
 	g_warning (_("Glade file is on crack! Make sure the correct "
 		     "file is installed!\nfile: %s widget: %s "
 		     "expected clist columns: %d"),
-		   filename, widget, columns);
+		   tmp, widget, columns);
+
+	g_free (tmp);
 
 	gtk_dialog_run (GTK_DIALOG (dlg));
 	gtk_widget_destroy (dlg);
@@ -265,11 +278,15 @@ static void
 glade_helper_no_interface (const char *filename)
 {
 	GtkWidget *dlg;
+	char *tmp;
+
+	tmp = ve_filename_to_utf8 (filename);
 	
 	dlg = ve_hig_dialog_new (NULL /* parent */,
 				 0 /* flags */,
 				 GTK_MESSAGE_ERROR,
 				 GTK_BUTTONS_OK,
+				 FALSE /* markup */,
 				 _("Cannot load user interface"),
 				 _("An error occured while loading the user "
 				   "interface from file %s.  "
@@ -278,13 +295,15 @@ glade_helper_no_interface (const char *filename)
 				   "%s cannot continue and will exit now.  "
 				   "You should check your "
 				   "installation of %s or reinstall %s."),
-				 filename,
+				 tmp,
 				 PACKAGE,
 				 PACKAGE,
 				 PACKAGE);
 	gtk_dialog_set_has_separator (GTK_DIALOG (dlg), FALSE);
 	g_warning (_("No interface could be loaded, BAD! (file: %s)"),
-		   filename);
+		   tmp);
+
+	g_free (tmp);
 
 	gtk_dialog_run (GTK_DIALOG (dlg));
 	gtk_widget_destroy (dlg);
